<?php

	/*
	Plugin Name: Cart Total Weight Adjustment
	Plugin URI: https://www.pluginhive.com/plugins/
	Description: This plugin will add additional weight to the cart total weight.
	Version: 1.0
	Author: PluginHive
	Author URI: https://pluginhive.com/
	Text Domain: ph_cart_total_weight_adjustment

	WC requires at least: 2.6.0
	WC tested up to: 3.5.7

	Supported Plugin(s): WooCommerce Table Rate Shipping Pro Plugin - v 3.1.3

	*/

	if ( ! defined( 'ABSPATH' ) ) {
		exit;	// Exit if accessed directly
	}

	function ph_cart_total_weight_adjustment_activation_check(){

		if ( !is_plugin_active('woocommerce-shipping-pro/woocommerce-shipping-pro.php') ){
			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the Shipping Discount Based On Cart Subtotal without activating WooCommerce Shipping Pro with Table Rate. Kindly activate <b>WooCommerce Shipping Pro with Table Rate</b> and then try again", "ph_cart_total_weight_adjustment" ), "", array('back_link' => 1 ));
		}
	}

	register_activation_hook( __FILE__, 'ph_cart_total_weight_adjustment_activation_check' );

	if ( in_array( 'woocommerce-shipping-pro/woocommerce-shipping-pro.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ){

		function add_ph_cart_total_weight_adjustment() {

			if ( ! class_exists( 'add_ph_total_weight_adjustment' ) ){
				class add_ph_total_weight_adjustment extends WC_Shipping_Method{

					public function __construct(){
						$this->id                 = 'ph_cart_total_weight_adjustment';
						$this->method_title       = __( 'Cart Weight Adjustment', 'ph_cart_total_weight_adjustment');
						$this->method_description = __( 'Add additional weight to the cart total weight.', 'ph_cart_total_weight_adjustment');
						
						add_action( 'admin_enqueue_scripts', array($this,'ph_cart_admin_enqueue'));

						$this->init();
					}

					function init() {

						$this->init_form_fields();
						$this->init_settings();

						add_filter( 'ph_shipping_pro_total_weight', array( $this, 'ph_add_additional_weight'), 15, 2 );	
						add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
					}

					function init_form_fields() {

						$this->form_fields = array(

							'cart_weight_adjustment' => array(
								'type'			=>	'adjustment_weight',
							)					

						);
					}

					public function generate_adjustment_weight_html()
					{
						$tool_tip_icon = plugins_url("woocommerce/assets/images/help.png");

						ob_start();
						?>
						<style type="text/css">
							.widefat th input, .widefat td input
							{
								margin: 0px;
								border-radius: 5px;
							}

							.widefat .check-column
							{
								padding: 10px !important;
								vertical-align: middle;
								text-align: right;
							}

							.weight_adjustment_table th, .weight_adjustment_table td
							{
								text-align: center;
								padding: 15px;
							}

							.ph-tooltip
							{
								position: relative;
								top: 4px;
							}

							.ph-tooltip .ph-tooltiptext
							{
								visibility: hidden;
								width: 150px;
								background-color: #333;
								color: #fff;
								text-align: center;
								border-radius: 3px; 
								padding: .618em 1em;
								font-size: .8em;
								position: absolute;
								z-index: 1;
							}

							.ph-tooltip:hover .ph-tooltiptext
							{
								visibility: visible;
							}

						</style>

						<table class="widefat posts weight_adjustment_table">

							<thead>
								<tr>
									<th class="check-column"><input type="checkbox" /></th>
									<th colspan="2">
										Cart Weight Range
										<?php
										echo '<span class="ph-tooltip"><img src="'.$tool_tip_icon.'" height="18" width="18" /><span class="ph-tooltiptext">Set up Cart Total Weight - Range for which you want to add Additional Weight.</span></span>'
										?>
									</th>
									<th> Additional Weight
										<?php
										echo '<span class="ph-tooltip"><img src="'.$tool_tip_icon.'" height="18" width="18" /><span class="ph-tooltiptext">This value will be added to the Cart Total Weight</span></span>'
										?>
									</th>
								</tr>
							</thead>

							<tbody>
								<?php
								$this->cart_weight_adjustment = ( isset($this->settings['cart_weight_adjustment']) && !empty($this->settings['cart_weight_adjustment']) ) ? $this->settings['cart_weight_adjustment'] : array();

								if ( $this->cart_weight_adjustment ) {
									foreach ( $this->cart_weight_adjustment as $key => $cart_weight ) {

										?>
										<tr>
											<td class="check-column"><input type="checkbox" /></td>
											<td><input type="number" name="min_cart_weight[<?php echo $key; ?>]" value="<?php echo esc_attr( $cart_weight['min_cart_weight'] ); ?>" placeholder="Min" min="0" step="any"></td>
											<td><input type="number" name="max_cart_weight[<?php echo $key; ?>]" value="<?php echo esc_attr( $cart_weight['max_cart_weight'] ); ?>" placeholder="Max" min="0" step="any"></td>
											<td><input type="number" name="additional_weight[<?php echo $key; ?>]" value="<?php echo esc_attr( $cart_weight['additional_weight'] ); ?>" placeholder="Additional Weight" min="0" step="any"></td>

										</tr>
									<?php }
								}
								?>

							</tbody>

							<tfoot>
								<tr>
									<th colspan="4" style="text-align: right;">
										<a href="#" class="button insert"><?php _e( 'Add New'); ?></a>
										<a href="#" class="button remove"><?php _e( 'Remove'); ?></a>
									</th>
								</tr>
							</tfoot>
						</table>

						<?php
						return ob_get_clean();
					}

					public function validate_adjustment_weight_field( $key =array() ) {

						$cart_weight_adjustment = array();

						$min_cart_weight	= isset( $_POST['min_cart_weight'] ) ? $_POST['min_cart_weight'] : array();
						$max_cart_weight	= isset( $_POST['max_cart_weight'] ) ? $_POST['max_cart_weight'] : array();
						$additional_weight	= isset( $_POST['additional_weight'] ) ? $_POST['additional_weight'] : array();

						if( !empty( array_keys( $additional_weight )) )
						{
							for ( $i = 0; $i <= max( array_keys( $additional_weight ) ); $i ++ ) {

								if (empty( $additional_weight[ $i] ) )
									continue;

								$cart_weight_adjustment[] = array(
									'min_cart_weight'	=> floatval( $min_cart_weight[ $i ] ),
									'max_cart_weight'	=> floatval( $max_cart_weight[ $i ] ),
									'additional_weight'	=> floatval( $additional_weight[ $i ] ),
								);
							}
						}

						return $cart_weight_adjustment;
					}

					function ph_cart_admin_enqueue()
					{
						wp_enqueue_script('cart_admin_shipping_rules', plugins_url('/resources/adminscript.js', __FILE__ ));
					}	

					public	function ph_add_additional_weight( $total_weight, $package_items )
					{
						$cart_weight_adjustment = isset($this->settings['cart_weight_adjustment']) ? $this->settings['cart_weight_adjustment'] : array();

						if( is_array($cart_weight_adjustment) && !empty($cart_weight_adjustment) )
						{
							$flag = true;
							foreach ($cart_weight_adjustment as $key => $cart_weight) {

								if( $total_weight > $cart_weight['min_cart_weight'] && $total_weight <= $cart_weight['max_cart_weight'] && $flag )
								{
									$total_weight += $cart_weight['additional_weight'];
									$flag = false;
								}
							}
						}
						return $total_weight;
					}
				}
			}
		}

		add_action( 'woocommerce_shipping_init', 'add_ph_cart_total_weight_adjustment' );

		function add_ph_cart_total_weight_adjustment_addon( $methods ) {
			$methods['add_ph_cart_total_weight_adjustment'] = 'add_ph_total_weight_adjustment';
			return $methods;
		}

		add_filter( 'woocommerce_shipping_methods', 'add_ph_cart_total_weight_adjustment_addon' );

		// Settings
		function settings_page_link( $links ) 
		{
			$settings_link = '<a href="admin.php?page=wc-settings&tab=shipping&section=ph_cart_total_weight_adjustment">Settings</a>';
			array_push( $links, $settings_link );
			return $links;
		}

		add_filter( "plugin_action_links_".plugin_basename(__FILE__), 'settings_page_link');


	}
	
